"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DB = void 0;
const apollo_boost_1 = require("apollo-boost");
const apollo_link_http_1 = require("apollo-link-http");
const cross_fetch_1 = __importDefault(require("cross-fetch"));
class DB {
    constructor(hasuraUri) {
        this.hasuraClient = new apollo_boost_1.ApolloClient({
            cache: new apollo_boost_1.InMemoryCache({
                addTypename: false
            }),
            defaultOptions: {
                query: {
                    fetchPolicy: 'network-only'
                }
            },
            link: apollo_link_http_1.createHttpLink({
                uri: `${hasuraUri}/v1/graphql`,
                fetch: cross_fetch_1.default,
                headers: {
                    'X-Hasura-Role': 'cardano-graphql'
                }
            })
        });
    }
    getMeta() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.hasuraClient.query({
                query: apollo_boost_1.gql `query {
          cardano {
              tip {
                  slotNo
              }
              slotDuration
              startTime
          }}`
            });
            const { tip, slotDuration, startTime } = (_a = result.data) === null || _a === void 0 ? void 0 : _a.cardano[0];
            const networkTipSlotNo = Math.round((Date.now() - new Date(`${startTime}Z`).getTime()) / slotDuration);
            const slotDiffFromNetworkTip = tip.slotNo - networkTipSlotNo;
            return {
                initialized: slotDiffFromNetworkTip >= -20,
                slotDiffFromNetworkTip,
                syncPercentage: (tip.slotNo / networkTipSlotNo) * 100
            };
        });
    }
}
exports.DB = DB;
//# sourceMappingURL=DB.js.map